# intel-compute-runtime.spec
#
# This spec file is for building RPM packages of Intel Compute Runtime (oneAPI Level Zero Loader and OpenCL Driver)
# for releases/24.35 branch.
#
# It is designed to be compatible with Fedora/RHEL-based systems.

%define commit 24.35.30872.32
%define short_commit 29547
%define _release %{commit}.%{_relprefix}%{?dist}

Name:           intel-compute-runtime
Version:        24.35.29547
Release:        %{_release}
Summary:        Intel Compute Runtime for OpenCL and Level Zero
License:        MIT
URL:            https://github.com/intel/compute-runtime
Source0:        https://github.com/intel/compute-runtime/archive/refs/tags/24.35.30872.32.tar.gz
# Alternatively, if fetching directly from the branch is preferred (less common for releases):
# Source0:        https://github.com/intel/compute-runtime/archive/releases/24.35/%{short_commit}.tar.gz
# This assumes the releases/24.35 branch is tagged or a specific commit hash within that branch is used.
# For a specific release tag, the first Source0 is more appropriate.

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  libwayland-client-devel
BuildRequires:  libdrm-devel
BuildRequires:  opencl-headers
BuildRequires:  level-zero-headers
BuildRequires:  libva-devel
BuildRequires:  libvpl-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  spdlog-devel
BuildRequires:  gtest-devel
BuildRequires:  libtpms-devel
BuildRequires:  protobuf-devel
BuildRequires:  libxml2-devel
BuildRequires:  json-c-devel
BuildRequires:  zlib-devel
BuildRequires:  libcurl-devel
BuildRequires:  libuuid-devel
BuildRequires:  systemd-libs
BuildRequires:  clang-devel
BuildRequires:  llvm-devel
BuildRequires:  python3-devel
BuildRequires:  opencl-filesystem

Requires:       libwayland-client
Requires:       libdrm
Requires:       opencl-headers
Requires:       level-zero-headers
Requires:       libva
Requires:       libvpl
Requires:       libuuid
Requires:       systemd-libs
Requires:       opencl-filesystem
Requires:       intel-igc = %{version}-%{release}
Requires:       intel-ocloc = %{version}-%{release}
Requires:       intel-opencl = %{version}-%{release}
Requires:       intel-level-zero = %{version}-%{release}


%description
The Intel Compute Runtime for OpenCL and Level Zero provides the necessary
drivers and runtime components to enable OpenCL and oneAPI Level Zero
applications on Intel Graphics Processing Units (GPUs). This package is
built from the releases/24.35 branch.

%prep
%setup -q -n compute-runtime-%{commit}

%build
# Ensure we're in the source directory
# Default build type is Release, which is usually desired for packages.
%cmake \
    -DNEO_CMAKE_BUILD_TYPE=Release \
    -DCM_BUILD=OFF \
    -DCL_ICD_PREFIX_PATH=/usr \
    -DLOADER_INSTALL_DIR=/usr \
    -DL0_INSTALL_DIR=/usr \
    -DSUPPORT_OCL_ICD=ON \
    -DSUPPORT_L0=ON \
    -DNEO_DEBUG_API=OFF \
    -DSUPPORT_VC=ON \
    -DSUPPORT_XE_LPM=ON \
    -DSUPPORT_TGL_LP=ON \
    -DSUPPORT_PVC=ON \
    -DCMAKE_INSTALL_PREFIX=/usr

%cmake_build

%install
%cmake_install

# Install the OpenCL ICD file
install -D -m 0644 %{_builddir}/compute-runtime-%{commit}/install/usr/lib64/intel-opencl/OpenCL/vendors/intel.icd %{buildroot}%{_libdir}/OpenCL/vendors/intel.icd
install -D -m 0644 %{_builddir}/compute-runtime-%{commit}/install/usr/lib64/intel-opencl/OpenCL/vendors/intel_cm.icd %{buildroot}%{_libdir}/OpenCL/vendors/intel_cm.icd

# Install the Level Zero JSON file
install -D -m 0644 %{_builddir}/compute-runtime-%{commit}/install/usr/lib64/intel-oneapi-level-zero/intel_level_zero.json %{buildroot}%{_libdir}/oneapi/level_zero/intel_level_zero.json


%files
%license LICENSE
%{_libdir}/libigc.so*
%{_libdir}/libigdfcl.so*
%{_libdir}/libocloc.so*
%{_libdir}/libze_intel_gpu.so*
%{_libdir}/libocloc.so*
%{_libdir}/OpenCL/vendors/intel.icd
%{_libdir}/OpenCL/vendors/intel_cm.icd
%{_libdir}/oneapi/level_zero/intel_level_zero.json
# Depending on the build, other files might be generated (e.g., headers, utilities)
# If they are installed to standard paths by cmake_install, they should be listed here.
# For example, if there are headers installed to %{_includedir}/intel-compute-runtime
# %{_includedir}/intel-compute-runtime/

%changelog
* Fri Jun 21 2025 Your Name <your.email@example.com> - 24.35.29547-1
- Initial RPM package for intel-compute-runtime from releases/24.35 branch.
